@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 1999, 2000, 2001  Free Software Foundation, Inc.
+ * Copyright (C) 1999-2007  Free Software Foundation, Inc.
  *
  * This file is part of GNU gengetopt 
  *
@@ -18,13 +18,18 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
  */
 
-
 #include "argsdef.h"
 
-const char * arg_names [] = { (const char*)0, (const char*)0, "STRING", "INT", "SHORT", "LONG", "FLOAT", "DOUBLE", "LONGDOUBLE", "LONGLONG" };
+const char * arg_names [] = { (const char*)0, (const char*)0, "STRING", "INT",
+        "SHORT", "LONG", "FLOAT", "DOUBLE", "LONGDOUBLE", "LONGLONG", "ENUM" };
 
-const char * arg_types [] = { (const char*)0, "int", "char *", "int", "short", "long", "float", "double", "long double", "long long int" };
+const char * arg_type_constants [] = { "ARG_NO", "ARG_FLAG", "ARG_STRING",
+        "ARG_INT", "ARG_SHORT", "ARG_LONG", "ARG_FLOAT", "ARG_DOUBLE",
+        "ARG_LONGDOUBLE", "ARG_LONGLONG", "ARG_ENUM" };
 
-const char * arg_types_names [] = { (const char*)0, "int", "string", "int", "short", "long", "float", "double", "long_double", "long_long_int" };
+const char * arg_types [] = { (const char*)0, "int", "char *", "int", "short",
+        "long", "float", "double", "long double", "long long int", "enum" };
 
+const char * arg_types_names [] = { (const char*)0, "int", "string", "int",
+        "short", "long", "float", "double", "longdouble", "longlong", "int" };
 
