@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 1999, 2000, 2001, 2002  Free Software Foundation, Inc.
+ * Copyright (C) 1999-2007  Free Software Foundation, Inc.
  *
  * This file is part of GNU gengetopt
  *
@@ -48,7 +48,9 @@ class CmdlineParserCreator : public header_gen_class, public c_source_gen_class
 
   bool long_help;
   bool no_handle_help;
+  bool no_help;
   bool no_handle_version;
+  bool no_version;
   bool no_handle_error;
   bool conf_parser;
   bool string_parser;
@@ -75,9 +77,6 @@ class CmdlineParserCreator : public header_gen_class, public c_source_gen_class
         printf (" ");
     }
 
-  void do_update_arg (struct gengetopt_option *opt,
-                      ostream &stream, unsigned int indent, const string argstr,
-                      const string orig_argstr);
   void free_option(struct gengetopt_option *opt,
                    ostream &stream, unsigned int indent);
 
@@ -87,6 +86,7 @@ class CmdlineParserCreator : public header_gen_class, public c_source_gen_class
   string generate_getopt_string();
 
   // to be implemented in header_gen_class
+  virtual void generate_enum_types(ostream &stream, unsigned int indent);
   virtual void generate_option_arg(ostream &stream, unsigned int indent);
   virtual void generate_option_given(ostream &stream, unsigned int indent);
   virtual void generate_option_values_decl(ostream &stream, unsigned int indent);
@@ -94,11 +94,8 @@ class CmdlineParserCreator : public header_gen_class, public c_source_gen_class
   // to be implemented in c_source_gen_class
   virtual void generate_clear_arg(ostream &stream, unsigned int indent);
   virtual void generate_given_init(ostream &stream, unsigned int indent);
-  virtual void generate_struct_def(ostream &stream, unsigned int indent);
   virtual void generate_option_values(ostream &stream, unsigned int indent);
 
-  virtual void generate_handle_help(ostream &stream, unsigned int indent,
-                                    bool full_help = false);
   virtual void generate_handle_no_short_option(ostream &stream,
                                                unsigned int indent);
   virtual void generate_handle_option(ostream &stream, unsigned int indent);
@@ -106,11 +103,13 @@ class CmdlineParserCreator : public header_gen_class, public c_source_gen_class
   virtual void generate_handle_dependencies(ostream &stream, unsigned int indent);
   virtual void generate_handle_group(ostream &stream, unsigned int indent);
   virtual void generate_group_counters(ostream &stream, unsigned int indent);
-  virtual void generate_handle_version(ostream &stream, unsigned int indent);
+  virtual void generate_mode_counters(ostream &stream, unsigned int indent);
   virtual void generate_help_option_print(ostream &stream,
                                           unsigned int indent);
   virtual void generate_full_help_option_print(ostream &stream,
                                           unsigned int indent);
+  virtual void generate_detailed_help_option_print(ostream &stream,
+                                          unsigned int indent);
   virtual void generate_long_option_struct(ostream &stream,
                                            unsigned int indent);
   virtual void generate_reset_groups(ostream &stream, unsigned int indent);
@@ -132,10 +131,11 @@ class CmdlineParserCreator : public header_gen_class, public c_source_gen_class
   CmdlineParserCreator (char *function_name, char *struct_name,
                         char *unamed_options,
                         char *filename, char *header_ext, char *c_ext,
-                        bool long_help, bool no_handle_help,
-                        bool no_handle_version,
+                        bool long_help,
+                        bool no_handle_help, bool no_help,
+                        bool no_handle_version, bool no_version,
                         bool no_handle_error, bool conf_parser, bool string_parser,
-                        bool gen_version, bool gen_getopt,
+                        bool gen_version, bool gen_getopt, bool no_options,
                         const string &comment,
                         const string &outdir,
                         const string &show_required);
@@ -145,6 +145,8 @@ class CmdlineParserCreator : public header_gen_class, public c_source_gen_class
   virtual void generate_list_def(ostream &stream, unsigned int indent);
   virtual void generate_multiple_fill_array(ostream &stream, unsigned int indent);
   virtual void generate_update_multiple_given(ostream &stream, unsigned int indent);
+  virtual void generate_check_modes(ostream &stream, unsigned int indent);
+
   const string generate_purpose();
   const string generate_description();
   const string generate_usage_string(bool use_config_package = true);
@@ -154,8 +156,30 @@ class CmdlineParserCreator : public header_gen_class, public c_source_gen_class
    * help output
    * 
    * @param generate_hidden if true, include also the hidden options
+   * @param generate_details if true, include also the hidden options and
+   * details for options that have them.
    */
-  OptionHelpList *generate_help_option_list(bool generate_hidden = false);
+  OptionHelpList *generate_help_option_list(bool generate_hidden = false,
+          bool generate_details = false);
+  
+  /**
+   * generate the sharing between a list of help string, using the
+   * complete_list as the list with all the strings (both for hidden
+   * options and details, e.g.) and the smaller_list as the list
+   * with less strings
+   * 
+   * @param target_array the name of the array to copy to
+   * @param source_array the name of the array to copy from
+   */
+  void generate_help_option_print_from_lists(ostream &stream,
+          unsigned int indent, OptionHelpList *complete_list,
+          OptionHelpList *smaller_list, const std::string &target_array,
+          const std::string &source_array);
+  
+  /**
+   * Sets the has_arg_XXX by inspecting all the options types
+   */
+  void set_has_arg_types();
 };
 
 #endif /* _GM_H */
