@@ -44,32 +44,36 @@
      TOK_OPTION = 260,
      TOK_DEFGROUP = 261,
      TOK_GROUPOPTION = 262,
-     TOK_YES = 263,
-     TOK_NO = 264,
-     TOK_ON = 265,
-     TOK_OFF = 266,
-     TOK_FLAG = 267,
-     TOK_PURPOSE = 268,
-     TOK_DESCRIPTION = 269,
-     TOK_USAGE = 270,
-     TOK_DEFAULT = 271,
-     TOK_GROUP = 272,
-     TOK_GROUPDESC = 273,
-     TOK_MULTIPLE = 274,
-     TOK_ARGOPTIONAL = 275,
-     TOK_TYPESTR = 276,
-     TOK_SECTION = 277,
-     TOK_SECTIONDESC = 278,
-     TOK_TEXT = 279,
-     TOK_ARGS = 280,
-     TOK_VALUES = 281,
-     TOK_HIDDEN = 282,
-     TOK_DEPENDON = 283,
-     TOK_STRING = 284,
-     TOK_MLSTRING = 285,
-     TOK_CHAR = 286,
-     TOK_ARGTYPE = 287,
-     TOK_SIZE = 288
+     TOK_DEFMODE = 263,
+     TOK_MODEOPTION = 264,
+     TOK_YES = 265,
+     TOK_NO = 266,
+     TOK_ON = 267,
+     TOK_OFF = 268,
+     TOK_FLAG = 269,
+     TOK_PURPOSE = 270,
+     TOK_DESCRIPTION = 271,
+     TOK_USAGE = 272,
+     TOK_DEFAULT = 273,
+     TOK_GROUP = 274,
+     TOK_GROUPDESC = 275,
+     TOK_MODE = 276,
+     TOK_MODEDESC = 277,
+     TOK_MULTIPLE = 278,
+     TOK_ARGOPTIONAL = 279,
+     TOK_TYPESTR = 280,
+     TOK_SECTION = 281,
+     TOK_DETAILS = 282,
+     TOK_SECTIONDESC = 283,
+     TOK_TEXT = 284,
+     TOK_ARGS = 285,
+     TOK_VALUES = 286,
+     TOK_HIDDEN = 287,
+     TOK_DEPENDON = 288,
+     TOK_STRING = 289,
+     TOK_CHAR = 290,
+     TOK_ARGTYPE = 291,
+     TOK_SIZE = 292
    };
 #endif
 /* Tokens.  */
@@ -78,39 +82,43 @@
 #define TOK_OPTION 260
 #define TOK_DEFGROUP 261
 #define TOK_GROUPOPTION 262
-#define TOK_YES 263
-#define TOK_NO 264
-#define TOK_ON 265
-#define TOK_OFF 266
-#define TOK_FLAG 267
-#define TOK_PURPOSE 268
-#define TOK_DESCRIPTION 269
-#define TOK_USAGE 270
-#define TOK_DEFAULT 271
-#define TOK_GROUP 272
-#define TOK_GROUPDESC 273
-#define TOK_MULTIPLE 274
-#define TOK_ARGOPTIONAL 275
-#define TOK_TYPESTR 276
-#define TOK_SECTION 277
-#define TOK_SECTIONDESC 278
-#define TOK_TEXT 279
-#define TOK_ARGS 280
-#define TOK_VALUES 281
-#define TOK_HIDDEN 282
-#define TOK_DEPENDON 283
-#define TOK_STRING 284
-#define TOK_MLSTRING 285
-#define TOK_CHAR 286
-#define TOK_ARGTYPE 287
-#define TOK_SIZE 288
+#define TOK_DEFMODE 263
+#define TOK_MODEOPTION 264
+#define TOK_YES 265
+#define TOK_NO 266
+#define TOK_ON 267
+#define TOK_OFF 268
+#define TOK_FLAG 269
+#define TOK_PURPOSE 270
+#define TOK_DESCRIPTION 271
+#define TOK_USAGE 272
+#define TOK_DEFAULT 273
+#define TOK_GROUP 274
+#define TOK_GROUPDESC 275
+#define TOK_MODE 276
+#define TOK_MODEDESC 277
+#define TOK_MULTIPLE 278
+#define TOK_ARGOPTIONAL 279
+#define TOK_TYPESTR 280
+#define TOK_SECTION 281
+#define TOK_DETAILS 282
+#define TOK_SECTIONDESC 283
+#define TOK_TEXT 284
+#define TOK_ARGS 285
+#define TOK_VALUES 286
+#define TOK_HIDDEN 287
+#define TOK_DEPENDON 288
+#define TOK_STRING 289
+#define TOK_CHAR 290
+#define TOK_ARGTYPE 291
+#define TOK_SIZE 292
 
 
 
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 118 "parser.yy"
+#line 139 "parser.yy"
 {
     char   *str;
     char    chr;
@@ -121,7 +129,7 @@ typedef union YYSTYPE
     struct multiple_size *multiple_size;
 }
 /* Line 1489 of yacc.c.  */
-#line 125 "parser.h"
+#line 133 "parser.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
